# medatetime: Fast RFC3339 compliant date-time library

`medatetime` is a fork of [`udatetime`](https://github.com/freach/udatetime) with the following changes applied:

- faster clock for `utcnow()`, with microseconds support ([#36](https://github.com/freach/udatetime/pull/36))
- fixes for deepcopy and pickle ([#37](https://github.com/freach/udatetime/pull/37))


